@@ -17,11 +17,11 @@ a Challonge tournament.
 
 =head1 VERSION
 
-Version 0.31
+Version 1.00
 
 =cut
 
-our $VERSION = '0.31';
+our $VERSION = '1.00';
 
 =head1 SUBROUTINES/METHODS
 
@@ -107,7 +107,7 @@ sub update
 		if((ref $args eq "HASH") && ((! defined $args->{scores_csv}) ||
 			(ref $args->{scores_csv} ne "ARRAY")))
 		{
-			carp "Required argument 'scores_csv' as an array reference";
+			croak "Required argument 'scores_csv' as an array reference";
 			return undef;
 		}
 
@@ -258,16 +258,16 @@ sub attributes
 	return $self->{match};
 }
 
-=head2 index
+=head2 attachments
 
 Returns an arrayref of C<WWW::Challonge::Match::Attachment> objects for every
 attachment the match has.
 
-	my $attachments = $m->index;
+	my $attachments = $m->attachments;
 
 =cut
 
-sub index
+sub attachments
 {
 	my $self = shift;
 
@@ -295,20 +295,23 @@ sub index
 	return $attachments;
 }
 
-=head2 show
+=head2 attachment
 
 Returns a single C<WWW::Challonge::Match::Attachment> object for the
 attachment with the given ID:
 
-	my $ma = $m->show(124858);
+	my $ma = $m->attachment(124858);
 
 =cut
 
-sub show
+sub attachment
 {
 	my $self = shift;
 	my $atth = shift;
 
+	# Die on no arguments:
+	croak "No arguments given" unless(defined $atth);
+
 	# Get the key, REST client, tournament url and id:
 	my $key = $self->{key};
 	my $client = $self->{client};
@@ -333,7 +336,7 @@ sub show
 	return $attachment;
 }
 
-=head2 create
+=head2 new_attachment
 
 Creates a new match attachment and returns the resulting
 C<WWW::Challonge::Match::Attachment> object. Takes the following arguments, at
@@ -357,24 +360,27 @@ Text to the describte the file or URL, or it can simply be standalone text.
 =back
 
 	# A simple URL:
-	my $ma = $m->create({
+	my $ma = $m->new_attachment({
 		url => http://www.example.com/image.png",
 		description => "An example URL",
 	});
 
 	# File uploads require a filename:
-	my $ma = $m->create({
+	my $ma = $m->new_attachment({
 		asset => "example.png",
 		description => "An example file",
 	});
 
 =cut
 
-sub create
+sub new_attachment
 {
 	my $self = shift;
 	my $args = shift;
 
+	# Die on no arguments:
+	croak "No arguments given" unless(defined $args);
+
 	# Get the key, REST client, tournament url and id:
 	my $key = $self->{key};
 	my $client = $self->{client};
@@ -427,7 +433,7 @@ sub __args_are_valid
 	{
 		if($result !~ /^\d*-\d*$/)
 		{
-			carp "Results must be given in the format \"x-y\", where x and y ".
+			croak "Results must be given in the format \"x-y\", where x and y ".
 			"are integers";
 			return undef;
 		}
@@ -441,7 +447,7 @@ sub __args_are_valid
 			next unless(defined $args->{$arg});
 			if($args->{$arg} !~ /^\d*$/)
 			{
-				carp "Argument '", $arg, "' must be an integer";
+				croak "Argument '", $arg, "' must be an integer";
 				return undef;
 			}
 		}
@@ -482,7 +488,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc WWW::Challonge::Match
 
-
 You can also look for information at:
 
 =over 4
