@@ -18,11 +18,11 @@ attachement within a Challonge tournament.
 
 =head1 VERSION
 
-Version 0.31
+Version 1.00
 
 =cut
 
-our $VERSION = '0.31';
+our $VERSION = '1.00';
 
 =head1 SUBROUTINES/METHODS
 
@@ -31,7 +31,7 @@ our $VERSION = '0.31';
 Takes a hashref representing the match attachment, the tournament id, the API
 key and the REST client and turns it into an object. This is mostly used by the
 module itself. To see how to create a match attachment, see
-L<WWW::Challonge::Match/create>.
+L<WWW::Challonge::Match/new_attachment>.
 
 	my $ma = WWW::Challonge::Match::Attachment->new($match, $id, $key, $client);
 
@@ -59,7 +59,7 @@ sub new
 =head2 update
 
 Updates the attributes of the match attachment. Takes the same arguments as
-L<WWW::Challonge::Match/create>.
+L<WWW::Challonge::Match/new_attachment>.
 
 	$ma->update({ url => "https://www.example.com/example2.png" });
 
@@ -73,6 +73,9 @@ sub update
 	# Do not operate on a dead attachment:
 	return __is_kill unless($self->{alive});
 
+	# Die on no errors:
+	croak "No arguments given" unless(defined $args);
+
 	# Get the key, REST client, tournament url and id:
 	my $key = $self->{key};
 	my $client = $self->{client};
@@ -227,7 +230,7 @@ sub __args_are_valid
 		{
 			if(! -f $args->{$arg})
 			{
-				carp "No such file: '" . $args->{$arg} . "'";
+				croak "No such file: '" . $args->{$arg} . "'";
 				return undef;
 			}
 		}
@@ -235,7 +238,7 @@ sub __args_are_valid
 		{
 			if($args->{$arg} !~ m{^(?:https?|ftp)://})
 			{
-				carp "URL must start with 'http://', 'https://' or 'ftp://'";
+				croak "URL must start with 'http://', 'https://' or 'ftp://'";
 				return undef;
 			}
 		}
