@@ -17,11 +17,11 @@ WWW::Challonge::Tournament - A class representing a single Challonge tournament.
 
 =head1 VERSION
 
-Version 0.31
+Version 1.00
 
 =cut
 
-our $VERSION = '0.31';
+our $VERSION = '1.00';
 
 =head1 SUBROUTINES/METHODS
 
@@ -29,7 +29,7 @@ our $VERSION = '0.31';
 
 Takes a hashref representing the tournament, the API key and the REST client
 and turns it into an object. This is mostly used by the module itself, to
-create a new tournament see L<WWW::Challonge/create>.
+create a new tournament see L<WWW::Challonge/new_tournament>.
 
 	my $t = WWW::Challonge::Tournament->new($tournament, $key, $client);
 
@@ -55,7 +55,7 @@ sub new
 =head2 update
 
 Updates specific attributes of a tournament. For a full list, see
-L<WWW::Challonge/create>. Unlike that method, however, all of the arguments
+L<WWW::Challonge/new_tournament>. Unlike that method, however, all of the arguments
 are optional.
 
 	$t->update({
@@ -73,6 +73,9 @@ sub update
 	# Do not operate on a dead tournament:
 	return __is_kill unless($self->{alive});
 
+	# Die on no errors:
+	croak "No arguments given" unless(defined $args);
+
 	# Get the key, REST client and tournament url:
 	my $key = $self->{key};
 	my $client = $self->{client};
@@ -177,7 +180,6 @@ sub process_check_ins
 	my $response = $client->request(WWW::Challonge::__json_request(
 		"$HOST/tournaments/$url/process_check_ins.json", "POST", $params));
 
-	# Check for any errors:
 	WWW::Challonge::__handle_error $response if($response->is_error);
 
 	return 1;
@@ -503,19 +505,19 @@ sub attributes
 	return $self->{tournament};
 }
 
-=head2 participant_index
+=head2 participants
 
 Returns an arrayref of C<WWW::Challonge::Participant> objects for every
 participant in the tourney.
 
-	my $p = $t->participant_index;
+	my $p = $t->participants;
 	for my $participant(@{$p})
 	{
 		...
 
 =cut
 
-sub participant_index
+sub participants
 {
 	my $self = shift;
 
@@ -545,16 +547,16 @@ sub participant_index
 	return $participants;
 }
 
-=head2 participant_show
+=head2 participant
 
 Returns a single C<WWW::Challonge::Participant> object representing the
 participant with the given unique ID.
 
-	my $p = $t->participant_show(24279875);
+	my $p = $t->participant(24279875);
 
 =cut
 
-sub participant_show
+sub participant
 {
 	my $self = shift;
 	my $participant = shift;
@@ -562,6 +564,9 @@ sub participant_show
 	# Do not operate on a dead tournament:
 	return __is_kill unless($self->{alive});
 
+	# Die on no arguments:
+	croak "No arguments given" unless(defined $participant);
+
 	# Get the key, REST client and url:
 	my $key = $self->{key};
 	my $client = $self->{client};
@@ -576,12 +581,12 @@ sub participant_show
 	WWW::Challonge::__handle_error $response if($response->is_error);
 
 	# If so, create an object and return it:
-	my $p = WWW::Challonge::Participant->new(from_json($client->responseContent),
-		$key, $client);
+	my $p = WWW::Challonge::Participant->new(
+		from_json($response->decoded_content), $key, $client);
 	return $p;
 }
 
-=head2 participant_create
+=head2 new_participant
 
 Adds a new participant to the tournament, and if successful returns the newly
 created C<WWW::Challonge::Participant> object. The possible arguments are as
@@ -619,14 +624,14 @@ characters.
 
 =back
 
-	my $p = $t->participant_create({
+	my $p = $t->new_participant({
 		name => "test",
 		seed => 4
 	});
 
 =cut
 
-sub participant_create
+sub new_participant
 {
 	my $self = shift;
 	my $args = shift;
@@ -642,9 +647,9 @@ sub participant_create
 
 	# Fail if name or challonge_username or email is not provided:
 	unless((defined $args->{name}) || (defined $args->{challonge_username}) ||
-		defined $args->{email})
+		(defined $args->{email}))
 	{
-		carp "Name, email or Challonge username are required to create a new ".
+		croak "Name, email or Challonge username are required to create a new ".
 			"participant.\n";
 		return undef;
 	}
@@ -668,20 +673,20 @@ sub participant_create
 	return $p;
 }
 
-=head2 match_index
+=head2 matches
 
 Returns an arrayref of C<WWW::Challonge::Match> objects for every
 match in the tourney. The tournament must be in progress before this will
 return anything useful.
 
-	my $m = $t->match_index;
+	my $m = $t->matches;
 	for my $match(@{$m})
 	{
 		...
 
 =cut
 
-sub match_index
+sub matches
 {
 	my $self = shift;
 
@@ -711,16 +716,16 @@ sub match_index
 	return $matches;
 }
 
-=head2 match_show
+=head2 match
 
 Returns a single C<WWW::Challonge::Match> object representing the match with
 the given unique ID.
 
-	my $m = $t->match_show(24279875);
+	my $m = $t->match(24279875);
 
 =cut
 
-sub match_show
+sub match
 {
 	my $self = shift;
 	my $match = shift;
@@ -728,6 +733,9 @@ sub match_show
 	# Do not operate on a dead tournament:
 	return __is_kill unless($self->{alive});
 
+	# Die on no arguments:
+	croak "No arguments given" unless(defined $match);
+
 	# Get the key, REST client and url:
 	my $key = $self->{key};
 	my $client = $self->{client};
@@ -742,7 +750,7 @@ sub match_show
 	WWW::Challonge::__handle_error $response if($response->is_error);
 
 	# If so, create an object and return it:
-	my $m = WWW::Challonge::Match->new(from_json($client->responseContent),
+	my $m = WWW::Challonge::Match->new(from_json($response->decoded_content),
 		$key, $client);
 	return $m;
 }
@@ -758,7 +766,6 @@ that has been successfully destroyed.
 sub __is_kill
 {
 	croak "Tournament has been destroyed";
-	return undef;
 }
 
 =head2 __args_are_valid
@@ -772,13 +779,6 @@ sub __args_are_valid
 {
 	my $args = shift;
 
-	# Check it is a hashref:
-	unless(ref $args eq "HASH")
-	{
-		carp "Argument must be a hashref";
-		return undef;
-	}
-
 	# The possible parameters, grouped together by the kind of input they take.
 	my %valid_args = (
 		string => [
@@ -898,12 +898,52 @@ sub __args_are_valid
 	for my $arg(@{$valid_args{datetime}})
 	{
 		next unless(defined $args->{$arg});
-		# Make sure the argument is a valid datetime:
-#		if($args->{$arg} !~ /^$/)
-#		{
-#			carp "Value '", $args->{$arg}, "' is not a valid datetime for " .
-#				"argument '" . $arg . "'";
-#		}
+
+		# Check if we have a DateTime object:
+		eval { $args->{$arg}->isa("DateTime") } or my $at = $@;
+
+		# If so, get the ISO8601 string:
+		if($at)
+		{
+			$args->{$arg} = $args->{$arg}->iso8601;
+		}
+		# If not make sure the argument is a valid datetime:
+		elsif($args->{$arg} !~ /
+			^\d{4}- # The year, mandatory in all cases
+				(?:
+					(?:
+						\d{2}-\d{2} # Month and day
+							(?:
+								T\d{2}:\d{2}:\d{2} # Hours, minutes, seconds
+									(?:
+										(?:
+											\+\d{2}:\d{2} # Timezone
+										)
+										|
+										(?:
+											Z # UTC
+										)
+									)
+							)?
+					)
+					|
+					(?:
+						W\d{2} # Week
+							(?:
+								-\d # Date with week number
+							)?
+					)
+					|
+					(?:
+						\d{3} # Ordinal date
+					)
+				)
+			$
+		/x)
+		{
+			croak "Value '", $args->{$arg}, "' is not a valid datetime for " .
+				"argument '" . $arg . "'";
+		}
 	}
 
 	# Finally, check if there are any unrecognised arguments, but just ignore
